@@ -19,8 +19,6 @@ train[-labeled.index,cls] <- NA
 
 m <- LinearTSVMSSLR() %>% fit(Class ~ ., data = train)
 
-#Accuracy
-predict(m,test) %>%
-  bind_cols(test) %>%
-  metrics(truth = "Class", estimate = .pred_class)
 
+#Accesing model from RSSL
+model <- m$model
