@@ -19,6 +19,9 @@ train[-labeled.index,cls] <- NA
 
 m <- USMLeastSquaresClassifierSSLR() %>% fit(Class ~ ., data = train)
 
+#Accesing model from RSSL
+model <- m$model
+
 #Accuracy
 predict(m,test) %>%
   bind_cols(test) %>%
